=== modified file 'lib/lp/archiveuploader/dscfile.py'
--- lib/lp/archiveuploader/dscfile.py	2011-05-20 06:01:37 +0000
+++ lib/lp/archiveuploader/dscfile.py	2011-05-20 06:09:38 +0000
@@ -65,7 +65,6 @@
 from lp.registry.interfaces.sourcepackage import SourcePackageFileType
 from lp.registry.interfaces.sourcepackagename import ISourcePackageNameSet
 from lp.services.encoding import guess as guess_encoding
-from lp.services.mail.signedmessage import strip_pgp_signature
 from lp.soyuz.enums import (
     ArchivePurpose,
     SourcePackageFormat,
@@ -133,7 +132,7 @@
                 self.raw_content, self.filepath)
         else:
             self.logger.debug("%s can be unsigned." % self.filename)
-            self.parsed_content = strip_pgp_signature(self.raw_content)
+            self.parsed_content = self.raw_content
         try:
             self._dict = parse_tagfile_content(
                 self.parsed_content, filename=self.filepath)

=== modified file 'lib/lp/archiveuploader/tagfiles.py'
--- lib/lp/archiveuploader/tagfiles.py	2011-05-20 06:01:37 +0000
+++ lib/lp/archiveuploader/tagfiles.py	2011-05-20 06:09:38 +0000
@@ -85,10 +85,13 @@
 
     The mandatory first argument is the contents of the tag file as a
     string.
+
+    An OpenPGP cleartext signature will be stripped before parsing if
+    one is present.
     """
 
     with tempfile.TemporaryFile() as f:
-        f.write(content)
+        f.write(strip_pgp_signature(content))
         f.seek(0)
         stanzas = list(apt_pkg.ParseTagFile(f))
     if len(stanzas) != 1:
@@ -113,13 +116,9 @@
 
     The mandatory first argument is the filename of the tag file, and
     the contents of that file is passed on to parse_tagfile_content.
-
-    This will also strip any OpenPGP cleartext signature that is present
-    before handing the data over.
     """
-    changes_in = open(filename, "r")
-    content = strip_pgp_signature(changes_in.read())
-    changes_in.close()
+    with open(filename, "r") as changes_in:
+        content = changes_in.read()
     if not content:
         raise TagFileParseError("%s: empty file" % filename)
     return parse_tagfile_content(content, filename=filename)

=== modified file 'lib/lp/soyuz/scripts/processaccepted.py'
--- lib/lp/soyuz/scripts/processaccepted.py	2011-05-20 06:01:37 +0000
+++ lib/lp/soyuz/scripts/processaccepted.py	2011-05-20 06:09:38 +0000
@@ -30,7 +30,6 @@
 from lp.bugs.interfaces.bugtask import BugTaskStatus
 from lp.registry.interfaces.distribution import IDistributionSet
 from lp.registry.interfaces.pocket import PackagePublishingPocket
-from lp.services.mail.signedmessage import strip_pgp_signature
 from lp.services.scripts.base import (
     LaunchpadScript,
     LaunchpadScriptFailure,
@@ -53,8 +52,7 @@
     The bugs is specified in the Launchpad-bugs-fixed header, and are
     separated by a space character. Nonexistent bug ids are ignored.
     """
-    contents = strip_pgp_signature(changes_file.read())
-    tags = Deb822Dict(parse_tagfile_content(contents))
+    tags = Deb822Dict(parse_tagfile_content(changes_file.read()))
     bugs_fixed_line = tags.get('Launchpad-bugs-fixed', '')
     bugs = []
     for bug_id in bugs_fixed_line.split():

